Off-line signature systems only have the signature image as input.  They can be used in various environments such as banking.  The issues concerning an off-line system are what feature vector to use, how to preprocess the signature image, and what classification system to use.
