We have presented a technique for achieving off-line signature verification, using preprocessing steps, and a neural network classifier.  The performance of our system was over 90%.  This off-line system performs better than the nearest neighbor technique, and is less sensitive to variations in the training set.  The high performance shows that the preprocessor was good at preserving distinguishing signature features while eliminating less useful image data.
