An off-line signature verification system is designed.  The system uses a set of simple neural network classifiers, and both global signature features, and localized signature features.  The networks are trained on a set of authentic signatures, and skilled forgeries.  The many simple networks are trained by ada-boosting, and combine to give a final result.
