<?php
  // Configuration
  $pages = array("Abstract", "Objective", "Introduction", "Experiment", "Discussion", "Conclusions");
?>
<html>
<head>
<title>Off-line Signature Verification Using Neural Networks</title>
<link rel="stylesheet" href="default.css" type="text/css">
</head>
<body bgcolor=#009999>
<table width=100% border=0 cellspacing=10>
<tr>
<td colspan=2 align=center style="border: 2px solid #000999" bgcolor=#000000><font class="title1">EE547 Final Project</font>
<br><font class="title2">Off-line Signature Verification Using Neural Networks
</font></td>
</tr>
<tr>
<td valign=top><table border=0 bgcolor=#333333 cellspacing=5 cellpadding=5 style="border: 1px solid #000fff">
<?php

  foreach ($pages as $page) {
    echo "<tr><td><a href=\"index.php?loc=$page\">$page</a></td></tr>";
  }
?>
</table><br><a href="mailto:uim2@cornell.edu">U Moszkowicz</a><br><a href="mailto:alm19@cornell.edu">A Mehler</a></td>
<td align=left valign=top width=100%><font class="content">
<?php
  if (!$loc) $loc = $pages[0];
  echo "<font style=\"font-size: 14pt; font-style: bold;\"><b>$loc</b></font><br>";
  include("$loc.inc");
?>
</font>
</tr>
</table>
</body>
</html>
