.title1 {
  font-family: verdana, georgia, sans-serif;
  color: #00aaaa;
  font-size: 28pt;
}
.title2 {
  font-family: verdana, georgia, sans-serif;
  color: #00ffff;
  font-size: 14pt;
}
.content {
  font-family: georgia, verdana, sans-serif;
  color: #000000;
  font-size: 12pt;
}


a:link, a:visited, a:active, a:hover {
  text-decoration: none;
  color: #00ffff;
  font-size: 14pt;
}
a:hover {
  color: #fff888;
}
