Ada Boosting was the superior classifier.  After learning this, changes were made to the feature vector using the Ada Boost as a classifier.  When grid features were used, overall performance decreased.  Actually, the grid feature vector produced poorly on the 'Andrew Mehler' signature, and average on 'Bush'.  This may be caused by the compactness of the 'Mehler' signature, making the grid very sensitive to small changes.  The strokes feature vector had about the same performance for all cases, because it can adapt to images.<br><Br>

Also of interest is that nearest neighbor often performed well, but had some cases of extremely poor performance, bringing down its total performance.  This is because a nearest neighbor technique is sensitive to choice of database.  For optimal performance, we want samples as far apart as possible.  Since the feature dimension is very large, we must have a large database for good performance of the nearest neighbor technique.  It can quickly become too costly to run.  Neural network techniques are computationally intensive in training, but the classification once training has been done is quick.  The nearest neighbor technique is the opposite.<br><br>

Next, we tried training on global features only, expecting the performance to drop.  In fact the performance increased slightly.  To account for this we tried training with a feature vector of only the first stroke.  This caused very poor performance.  Next, only strokes, and no global data were used.  This again produced decent results.  This shows that the signatures can't be distinguished based on a small sample of them.  A single stroke could not discriminate very well, while 15 strokes (the max strokes for the experiment) performed well.  We still have the problem that only global features are the best performer, and either global or localized features outperform its combination.<br><br>

The global features performance can be attributed to the skillfulness of the forgeries.  If a professional forger attempted to reproduce a signature, we would expect global features to be almost identical, and we would have to resort to small local differences to tell them apart.<br><br>
